/*
  GetKey.ino

  This sketch demonstrats how GetKey function works.

  You have to install MGLCD library Ver.0.34 or later, which controls
 a GLCD module.  MGLCD library can be downloaded at the following web page:

  http://www3.big.or.jp/~schaft/hardware/MGLCD/

  This sketch shows the keys you pressed on your LCD screen.

  This sketch requires a 122X32 MGLCD shield that is introduced at the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product_MGLCD_shield_12232_C/index.html
  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad or the 4X5 keypad that are
introduced at the following web pages:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html (4X4)
  http://www3.big.or.jp/~schaft/hardware/product/keypad4X5/page001.html (4X5)

  This example code is in the public domain.
*/

// include library codes
#include <mglcd.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
int ain=A4;

#ifdef USBCON // Leonardo
mglcd_serial MGLCD(&Serial1,500000); // define serial LCD
#else // not Leonardo
mglcd_serial MGLCD(&Serial,500000); // define serial LCD
#endif

ResKeypad keypad(ain,16,RESKEYPAD_4X4); // enable this line if 4X4 keypad is used
//ResKeypad keypad(ain,20,RESKEYPAD_4X5); // enable this line if 4X5 keypad is used

// functions
void setup()
{
  // initialize LCD
  while(MGLCD.Reset());
  MGLCD.Locate(0,0);
  MGLCD.print("Press keys.");
  MGLCD.Locate(0,1);
} // setup

void loop()
{
  signed char key;

  key=keypad.GetKey();
  if(key>=0) {
    MGLCD.print("SW");
    MGLCD.print(key+1);
    MGLCD.print(' ');
  } // if
} // loop
